@@ -5,7 +5,7 @@ Made by Hedy Li,
 Code on GitHub
 """
 
-from typing import Optional
+from typing import Optional, List
 
 import requests
 
@@ -14,7 +14,7 @@ def fetch_repos(
     language: str = "",
     spoken_language_code: str = "",
     since: str = "daily",
-) -> dict:
+) -> List[dict]:
     """Fetch trending repositories on GitHub
 
     Parameters:
@@ -42,9 +42,15 @@ def fetch_repos(
     url: str = f"https://gtrend.yapie.me/repositories?language={language}&since={since}&spoken_language_code={spoken_language_code}"
 
     res = requests.get(url).json()
+    repos = []
     for repo in res:
         repo["fullname"] = f"{repo['author']}/{repo['name']}"
-    return res
+        repo_language = repo.get("language")
+        if language:
+            if not repo_language or repo_language.lower() != language.lower():
+                continue
+        repos.append(repo)
+    return repos
 
 
 def fetch_developers(language: str = "", since: str = "daily") -> dict:
